Bijzondere karakers in de tekst invoegen

Bijzondere karakers in de tekst invoegen | Inhoudsopgave

Met de knop 'Bijzondere Karakters' kunt u in de tekst bijzondere karakters, die soms op het toetsenbord lastig te vinden zijn, invoegen.
Voor het invoegen van een deze karakters wordt onderstaand keuzevenster getoond. Door het eenvoudigweg klikken op het gewenste karakter in het overzicht, wordt het op de huidige positie in de tekst ingevoegd.

Ga naar: Inhoudsopgave | Naar boven